package com.clx.performance.controller.pc;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.clx.performance.service.OwnerAccountService;
import com.clx.settlement.params.PageOwnerAccountListParam;
import com.clx.settlement.vo.pc.OwnerAccountRunningWaterRecordVO;
import com.clx.settlement.vo.pc.OwnerAccountVO;
import com.clx.settlement.params.PageOwnerMarginAccountParam;
import com.clx.settlement.params.PageOwnerPrepaidFreightAccountParam;
import com.msl.common.base.PageData;
import com.msl.common.convertor.aspect.UnitCovert;
import com.msl.common.result.Result;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Slf4j
@RestController
@RequestMapping("/pc/ownerAccount")
@Validated
@AllArgsConstructor
@Api(tags = "PC-资金管理")
public class OwnerAccountController {

    private final OwnerAccountService ownerAccountService;

    @ApiOperation(value = "查看资金管理列表", notes = "<br>By:胡宇帆")
    @PostMapping("/pageList")
    @UnitCovert(param = false)
    public Result<PageData<OwnerAccountVO>> pageList(@RequestBody PageOwnerAccountListParam param) {
        IPage<OwnerAccountVO> page = ownerAccountService.pageList(param);
        return Result.page(page.getRecords(), page.getTotal(), page.getPages());
    }

    @ApiOperation(value = "保证金账户详情流水列表", notes = "<br>By:胡宇帆")
    @PostMapping("/margin_account_page_list")
    @UnitCovert(param = false)
    public Result<PageData<OwnerAccountRunningWaterRecordVO>> marginAccountPageList(@RequestBody PageOwnerMarginAccountParam param) {
        IPage<OwnerAccountRunningWaterRecordVO> page = ownerAccountService.marginAccountPageList(param);
        return Result.page(page.getRecords(), page.getTotal(), page.getPages());
    }

    @ApiOperation(value = "预付金账户详情流水列表", notes = "<br>By:胡宇帆")
    @PostMapping("/prepaidFreight_account_page_list")
    @UnitCovert(param = false)
    public Result<PageData<OwnerAccountRunningWaterRecordVO>> prepaidFreightAccountPageList(@RequestBody PageOwnerPrepaidFreightAccountParam param) {
        IPage<OwnerAccountRunningWaterRecordVO> page = ownerAccountService.prepaidFreightAccountPageList(param);
        return Result.page(page.getRecords(), page.getTotal(), page.getPages());
    }

    @ApiOperation(value = "查看资金管理列表", notes = "<br>By:胡宇帆")
    @GetMapping("/account_info")
    @UnitCovert(param = false)
    public Result<List<OwnerAccountVO>> accountInfo(@RequestParam String ownerNo) {
        List<OwnerAccountVO> accountVOList = ownerAccountService.accountInfo(ownerNo);
        return Result.ok(accountVOList);
    }

    @ApiOperation(value = "账户充值", notes = "<br>By:胡宇帆")
    @GetMapping("/account_top_up")
    @UnitCovert(param = false)
    public Result<List<OwnerAccountVO>> account_top_up(@RequestParam String ownerNo) {
        List<OwnerAccountVO> accountVOList = ownerAccountService.accountInfo(ownerNo);
        return Result.ok(accountVOList);
    }

}
